@@ -17,6 +17,12 @@ def test_compare_requirements(repo_root):
     )
 
 
+def test_compare_requirements_ignore_docs(repo_root):
+    pcdsutils.requirements._compare_requirements(
+        args=['--ignore-docs', repo_root]
+    )
+
+
 def test_requirements_from_conda(repo_root):
     pcdsutils.requirements._requirements_from_conda(
         args=['-v', '--dry-run', repo_root]
